@@ -10,13 +10,14 @@ from urllib.error import HTTPError
 from torchaudio.datasets.utils import extract_archive
 
 from tests.utils import mark_slow
-from thunder.citrinet.blocks import Citrinet_encoder
+from thunder.blocks import conv1d_decoder
+from thunder.citrinet.blocks import Citrinet_encoder, EncoderConfig
 from thunder.citrinet.compatibility import (
     CitrinetCheckpoint,
     read_params_from_config_citrinet,
 )
-from thunder.quartznet.blocks import Quartznet_decoder
-from thunder.quartznet.compatibility import download_checkpoint, load_quartznet_weights
+from thunder.quartznet.compatibility import load_quartznet_weights
+from thunder.utils import download_checkpoint
 
 
 @mark_slow
@@ -32,8 +33,8 @@ def test_can_load_weights():
             encoder_params, initial_vocab, _ = read_params_from_config_citrinet(
                 config_path
             )
-            encoder = Citrinet_encoder(80, **encoder_params)
-            decoder = Quartznet_decoder(len(initial_vocab) + 1, 640)
+            encoder = Citrinet_encoder(EncoderConfig(**encoder_params))
+            decoder = conv1d_decoder(640, len(initial_vocab) + 1)
             load_quartznet_weights(
                 encoder, decoder, extract_path / "model_weights.ckpt"
             )
